/*
 * @Author: weisheng
 * @Date: 2023-04-17 12:51:22
 * @LastEditTime: 2023-04-20 15:01:53
 * @LastEditors: weisheng
 * @Description:
 * @FilePath: \uniapp-vue3-fant-ts\src\api\DemoApi.ts
 * 记得注释
 */
import http from '@/http/HttpClient'
import BaseResponse from '@/model/BaseResponse'
import Chanel from '@/model/Chanel'
import UserInfo from '@/model/UserInfo'
import getTime from '@/utils/getTime'
// 这里将API方法统一管理
export default class DemoApi {
  // 获取项目名称
  static getProjectNameList(data): Promise<BaseResponse<UserInfo>> {
    return http
      .server(data)
      .get(
        'bi-api/report/dataapi/project_info' +
        `?${Object.keys(getTime)
          .map((key) => {
            return `${key}=${getTime[key]}`
          })
          .join('&')}`
      )
      .then((res) => {
        return res.data
      })
  }

  // 获取油品型号
  // https://miniapp.zhangmushiye.com/bi-api/report/dataapi/project_oil_info
  static getOilTypeList(data): Promise<BaseResponse<UserInfo>> {
    let allData = {
      ...getTime,
      ...data
    }
    return http
      .server()
      .get(
        'bi-api/report/dataapi/project_oil_info' +
        `?${Object.keys({ ...getTime, ...data })
          .map((key) => {
            return `${key}=${allData[key]}`
          })
          .join('&')}`
      )
      .then((res) => {
        return res.data
      })
  }

  //  获取客户列表 getCustomerList
  static getCustomerList(data): Promise<BaseResponse<UserInfo>> {
    let allData = {
      ...getTime,
      ...data
    }
    return http
      .server()
      .get(
        'bi-api/report/dataapi/customerinfo_api' +
        `?${Object.keys(allData)
          .map((key) => {
            return `${key}=${allData[key]}`
          })
          .join('&')}`
      )
      .then((res) => {
        return res.data
      })
  }

  // https://miniapp.zhangmushiye.com/bi-api/report/dataapi/payment_api
  //开票公司
  static getInvoiceCompanyList(data): Promise<BaseResponse<UserInfo>> {
    let allData = {
      ...getTime,
      ...data
    }
    return http
      .server()
      .get(
        'bi-api/report/dataapi/payment_api' +
        `?${Object.keys(allData)
          .map((key) => {
            return `${key}=${allData[key]}`
          })
          .join('&')}`
      )
      .then((res) => {
        return res.data
      })
  }

  // 获取单价 /bi-api/report/dataapi/odsbuy
  static getUnitPriceList(data): Promise<BaseResponse<UserInfo>> {
    return http
      .server()
      .get(
        'bi-api/report/dataapi/odsbuy' +
        `?${Object.keys(data)
          .map((key) => {
            return `${key}=${data[key]}`
          })
          .join('&')}`
      )
      .then((res) => {
        return res.data
      })
  }

  // 获取客户getKehuList
  // /bi-api/report/dataapi/customerinfo_api
  static getKehuList(data): Promise<BaseResponse<UserInfo>> {
    const datas = { ...getTime, ...data };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/customerinfo_api' +
        `?${Object.keys(data)
          .map((key) => {
            return `${key}=${data[key]}`
          })
          .join('&')}`
      )
      .then((res) => {
        return res.data
      })
  }

  // config 结算管理 接口
  static getConfig(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server(data)
      .get('visual-api/paas/visualdev/OnlineDev/' + data + '/Config')
      .then((res) => {
        return res.data
      })
  }

  // 项目列表
  static getFormDataList(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .post('bi-api/cube/browser/' + data.dbLinkId, data)
      .then((res) => {
        return res.data
      })
  }

  // 获取表单Url
  static getSelectOptionsUrl(id): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .get('bi-api/report/dataapi/detail?id=' + id)
      .then((res) => {
        return res.data
      })
  }

  // 根据url拼接
  static getSelectOptionsUrlByParams(url): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .get(
        url +
        `?${Object.keys(getTime)
          .map((key) => {
            return `${key}=${getTime[key]}`
          })
          .join('&')}`
      )
      .then((res) => {
        return res.data
      })
  }

  // 编辑
  // https://miniapp.zhangmushiye.com/visual-api/paas/visualdev/OnlineDev/v2
  static getEditData(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .put(
        'visual-api/paas/visualdev/OnlineDev/v2/' + data.formKey + data.id,
        data.data
      )
      .then((res) => {
        return res.data
      })
  }

  static getAddData(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .post(
        'visual-api/paas/visualdev/OnlineDev/v2/' + data.formKey + data.id,
        data.data
      )
      .then((res) => {
        return res.data
      })
  }

  static deleteListData(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .delete(
        'visual-api/paas/visualdev/OnlineDev/' +
        data.formKey +
        data.id +
        '?dataJson=' +
        data.jsonData
      )
      .then((res) => {
        return res.data
      })
  }

  // 待办列表
  static todoList(data): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/List/1?currentPage=' + data.currentPage + '&pageSize=' + data.pageSize + '&keyword=' + data.keyword
    ).then((res) => {
      return res.data
    })
  }

  // 我发起的
  static myTodo(data): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowLaunch?currentPage=' + data.currentPage + '&pageSize=' + data.pageSize + '&keyword=' + data.keyword
    ).then((res) => {
      return res.data
    })
  }

  // 已办事宜
  static finishTodo(data): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/List/2?currentPage=' + data.currentPage + '&pageSize=' + data.pageSize + '&keyword=' + data.keyword
    ).then((res) => {
      return res.data
    })
  }

  // 抄送事宜
  static copyTodo(data): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/List/3?currentPage=' + data.currentPage + '&pageSize=' + data.pageSize + '&keyword=' + data.keyword
    ).then((res) => {
      return res.data
    })
  }

//   催办
  static cuiban(id): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowLaunch/Press/' + id
    ).then((res) => {
      return res.data
    })
  }

  //撤回
  static chehui(id: string, data: { handleOpinion: string }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      '/flow-api/paas/workflow/Engine/FlowBefore/Recall/' + id, data
    ).then((res) => {
      return res.data
    })
  }

  //审批通过
  static tongguo(id: string, processId: string, data: any): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowBefore/Audit/' + id + '/' + processId, data
    )
      .then((res) => {
        return res.data
      })
  }

  //审批拒绝
  static reject(id: string, data: any): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowBefore/Reject/' + id, data
    )
      .then((res) => {
        return res.data
      })
  }

  //重新发起
  static again(id: string): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/' + id
    )
      .then((res) => {
        return res.data
      })
  }


  //终止
  static overTodo(id: string, data: { handleOpinion: string }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post('flow-api/paas/workflow/Engine/FlowBefore/Cancel/' + id, data).then((res) => {
      return res.data
    })
  }

  static userList(data: { keyword: string }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'visual-api/paas/permission/Users/ImUser/Selector/0', data
    ).then((res) => {
      return res.data
    })
  }

  static userChild(id: string): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'visual-api/paas/permission/Users/ImUser/Selector/' + id
    ).then((res) => {
      return res.data
    })
  }

  // 表单详情
  static formInfo(id: string): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/' + id
    ).then((res) => {
      return res.data
    })
  }

  //委派
  static delegate(id: string, data: {
    freeApproverUserId: string,
    handleOpinion: string
  }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowBefore/Assign/' + id, data
    ).then((res) => {
      return res.data
    })
  }

  static transfer(id: string, data: { freeApproverUserId: string }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowBefore/Transfer/' + id, data
    ).then((res) => {
      return res.data
    })
  }


  static getLogin(): Promise<BaseResponse<Chanel[]>> {
    return http.server().get('api/blade_message/list?current=1&size=5').then((res) => {
      return res.data
    })
  }
  // 获取提油人 report/dataapi/driverleader_api
  static getTiYouRen(): Promise<BaseResponse<Chanel[]>> {
    const data = { ...getTime };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/driverleader_api' +
          `?${Object.keys(data)
            .map((key) => {
              return `${key}=${data[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // 获取提油人负责项目bi-api/report/dataapi/teamleader_api?
  static getTiYouRenProject(data): Promise<BaseResponse<Chanel[]>> {
    const datas = { ...getTime, ...data };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/teamleader_api' +
          `?${Object.keys(datas)
            .map((key) => {
              return `${key}=${datas[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }

  // 获取所有项目信息 bi-api/report/dataapi/onlybuyinfo_api
  static getProjectInfo(): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .get(
        'bi-api/report/dataapi/onlybuyinfo_api' +
          `?${Object.keys(getTime)
            .map((key) => {
              return `${key}=${getTime[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // bi-api/report/dataapi/driverinfo 获取指定司机负责项目
  static getDriverInfo(data): Promise<BaseResponse<Chanel[]>> {
    const datas = { ...getTime, ...data };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/driverinfo' +
          `?${Object.keys(datas)
            .map((key) => {
              return `${key}=${datas[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // bi-api/report/dataapi/driverinfo1_api获取所有司机信息
  static getDriverAllInfo(): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .get(
        'bi-api/report/dataapi/driverinfo1_api' +
          `?${Object.keys(getTime)
            .map((key) => {
              return `${key}=${getTime[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data
      })
  }

  // 待办列表
  static todoList(data): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/List/1?currentPage=' + data.currentPage + '&pageSize=' + data.pageSize + '&keyword=' + data.keyword
    ).then((res) => {
      return res.data
    })
  }

  // 我发起的
  static myTodo(data): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowLaunch?currentPage=' + data.currentPage + '&pageSize=' + data.pageSize + '&keyword=' + data.keyword
    ).then((res) => {
      return res.data
    })
  }

  // 已办事宜
  static finishTodo(data): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/List/2?currentPage=' + data.currentPage + '&pageSize=' + data.pageSize + '&keyword=' + data.keyword
    ).then((res) => {
      return res.data
    })
  }

  // 抄送事宜
  static copyTodo(data): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/List/3?currentPage=' + data.currentPage + '&pageSize=' + data.pageSize + '&keyword=' + data.keyword
    ).then((res) => {
      return res.data
    })
  }

//   催办
  static cuiban(id): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowLaunch/Press/' + id
    ).then((res) => {
      return res.data
    })
  }

  //撤回
  static chehui(id: string, data: { handleOpinion: string }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      '/flow-api/paas/workflow/Engine/FlowBefore/Recall/' + id, data
    ).then((res) => {
      return res.data
    })
  }

  //审批通过
  static tongguo(id: string, processId: string, data: any): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowBefore/Audit/' + id + '/' + processId, data
    )
      .then((res) => {
        return res.data
      })
  }

  //审批拒绝
  static reject(id: string, data: any): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowBefore/Reject/' + id, data
    )
      .then((res) => {
        return res.data
      })
  }

  //重新发起
  static again(id: string): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/' + id
    )
      .then((res) => {
        return res.data
      })
  }


  //终止
  static overTodo(id: string, data: { handleOpinion: string }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post('flow-api/paas/workflow/Engine/FlowBefore/Cancel/' + id, data).then((res) => {
      return res.data
    })
  }

  static userList(data: { keyword: string }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'visual-api/paas/permission/Users/ImUser/Selector/0', data
    ).then((res) => {
      return res.data
    })
  }

  static userChild(id: string): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'visual-api/paas/permission/Users/ImUser/Selector/' + id
    ).then((res) => {
      return res.data
    })
  }

  // 表单详情
  static formInfo(id: string): Promise<BaseResponse<Chanel[]>> {
    return http.server().get(
      'flow-api/paas/workflow/Engine/FlowBefore/' + id
    ).then((res) => {
      return res.data
    })
  }

  //委派
  static delegate(id: string, data: {
    freeApproverUserId: string,
    handleOpinion: string
  }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowBefore/Assign/' + id, data
    ).then((res) => {
      return res.data
    })
  }

  static transfer(id: string, data: { freeApproverUserId: string }): Promise<BaseResponse<Chanel[]>> {
    return http.server().post(
      'flow-api/paas/workflow/Engine/FlowBefore/Transfer/' + id, data
    ).then((res) => {
      return res.data
    })
  }


  static getLogin(): Promise<BaseResponse<Chanel[]>> {
    return http.server().get('api/blade_message/list?current=1&size=5').then((res) => {
      return res.data
    })
  }
  // 获取提油人 report/dataapi/driverleader_api
  static getTiYouRen(): Promise<BaseResponse<Chanel[]>> {
    const data = { ...getTime };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/driverleader_api' +
          `?${Object.keys(data)
            .map((key) => {
              return `${key}=${data[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // 获取提油人负责项目bi-api/report/dataapi/teamleader_api?
  static getTiYouRenProject(data): Promise<BaseResponse<Chanel[]>> {
    const datas = { ...getTime, ...data };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/teamleader_api' +
          `?${Object.keys(datas)
            .map((key) => {
              return `${key}=${datas[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }

  // 获取所有项目信息 bi-api/report/dataapi/onlybuyinfo_api
  static getProjectInfo(): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .get(
        'bi-api/report/dataapi/onlybuyinfo_api' +
          `?${Object.keys(getTime)
            .map((key) => {
              return `${key}=${getTime[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // bi-api/report/dataapi/driverinfo 获取指定司机负责项目
  static getDriverInfo(data): Promise<BaseResponse<Chanel[]>> {
    const datas = { ...getTime, ...data };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/driverinfo' +
          `?${Object.keys(datas)
            .map((key) => {
              return `${key}=${datas[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // bi-api/report/dataapi/driverinfo1_api获取所有司机信息
  static getDriverAllInfo(): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .get(
        'bi-api/report/dataapi/driverinfo1_api' +
          `?${Object.keys(getTime)
            .map((key) => {
              return `${key}=${getTime[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
}
